@@ -24,8 +24,13 @@ class UpdateModule:
         query = get_updates_for_item_query(item_id=item_id, limit=limit)
         return self.client.execute(query)
 
-    def fetch_board_updates_page(self, board_id, limit=100, page=1) -> List[Update]:
-        query = get_updates_for_board(board_id, limit, page)
+    def fetch_board_updates_page(self, board_id, limit=100, page=1, from_date: Optional[str] = None, to_date: Optional[str] = None) -> List[Update]:
+        """
+        Fetches a single page of updates from a board.
+        
+        Note: from_date and to_date parameters require Monday API version 2026-01+
+        """
+        query = get_updates_for_board(board_id, limit, page, from_date, to_date)
         response: MondayApiResponse = self.client.execute(query)
         return response.data.boards[0].updates
 
@@ -64,4 +69,35 @@ class UpdateModule:
             all_updates.extend(updates)
             page += 1
 
-        return all_updates
\ No newline at end of file
+        return all_updates
+
+    def fetch_board_updates_incremental(
+        self,
+        board_id: str,
+        limit: int = 100,
+        page: int = 1,
+        from_date: Optional[str] = None,
+        to_date: Optional[str] = None,
+    ) -> List[Update]:
+        """
+        Fetches updates from a board using Monday's native incremental fetch API.
+        Uses the API's built-in date filtering instead of client-side filtering.
+        
+        **Requires API version 2026-01 or later**
+        
+        Args:
+            board_id: The board ID to fetch updates from
+            limit: Maximum number of updates per page (default: 100)
+            page: Page number to fetch (default: 1)
+            from_date: Start date in ISO format (e.g., "2025-10-10T00:00:00Z")
+            to_date: End date in ISO format (e.g., "2025-11-11T00:00:00Z")
+        
+        Returns:
+            List of Update objects
+            
+        Note:
+            The from_date and to_date parameters require Monday API version 2026-01+.
+            If using an older API version, use fetch_board_updates() instead which 
+            provides client-side date filtering.
+        """
+        return self.fetch_board_updates_page(board_id, limit, page, from_date, to_date)
\ No newline at end of file
